@@ -1,19 +1,7 @@
-# Copyright (C) 2022 Greenbone AG
+# SPDX-FileCopyrightText: 2022-2023 Greenbone AG
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
 #
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 
 from typing import AsyncIterator, Iterable, Union
@@ -57,11 +45,31 @@ class GitHubAsyncRESTLabels(GitHubAsyncREST):
             for label in data:
                 yield label["name"]  # type: ignore
 
+    async def delete_all(self, repo: str, issue: Union[int, str]) -> None:
+        """
+        Deletes all labels in the issue/pr.
+
+        Args:
+            repo:   GitHub repository (owner/name) to use
+            issue:  Issue/Pull request number
+
+        Example:
+            .. code-block:: python
+
+                from pontos.github.api import GitHubAsyncRESTApi
+
+                async with GitHubAsyncRESTApi(token) as api:
+                    await api.labels.delete_all("foo/bar", 123)
+        """
+        api = f"/repos/{repo}/issues/{issue}/labels"
+        response = await self._client.delete(api)
+        response.raise_for_status()
+
     async def set_all(
         self, repo: str, issue: Union[int, str], labels: Iterable[str]
     ) -> None:
         """
-        Set labels in the issue/pr. Existing labels will be overwritten
+        Set labels in the issue/pr.
 
         Args:
             repo:   GitHub repository (owner/name) to use
