@@ -81,7 +81,7 @@ class GitHubAsyncRESTReleases(GitHubAsyncREST):
         response.raise_for_status()
         return Release.from_dict(response.json())
 
-    async def exists(self, repo: str, tag: str) -> bool:
+    async def exists(self, repo: str, tag: str) -> bool:  # type: ignore[return]
         """
         Check wether a GitHub release exists by tag
 
@@ -102,7 +102,14 @@ class GitHubAsyncRESTReleases(GitHubAsyncREST):
         """
         api = f"/repos/{repo}/releases/tags/{tag}"
         response = await self._client.get(api)
-        return response.is_success
+
+        if response.is_success:
+            return True
+
+        if response.status_code == 404:
+            return False
+
+        response.raise_for_status()
 
     async def get(self, repo: str, tag: str) -> Release:
         """
