@@ -55,6 +55,7 @@ class CVEChangesApi(NVDApi):
         token: Optional[str] = None,
         timeout: Optional[Timeout] = DEFAULT_TIMEOUT_CONFIG,
         rate_limit: bool = True,
+        request_attempts: int = 1,
     ) -> None:
         """
         Create a new instance of the CVE Change History API.
@@ -69,12 +70,14 @@ class CVEChangesApi(NVDApi):
                 rolling 30 second window.
                 See https://nvd.nist.gov/developers/start-here#divRateLimits
                 Default: True.
+            request_attempts: The number of attempts per HTTP request. Defaults to 1.
         """
         super().__init__(
             DEFAULT_NIST_NVD_CVE_HISTORY_URL,
             token=token,
             timeout=timeout,
             rate_limit=rate_limit,
+            request_attempts=request_attempts,
         )
 
     def changes(
