@@ -14,6 +14,7 @@ import httpx
 from pontos.changelog.conventional_commits import ChangelogBuilder
 from pontos.errors import PontosError
 from pontos.git import Git, ResetMode
+from pontos.git._git import DEFAULT_TAG_PREFIX
 from pontos.github.actions.core import ActionIO
 from pontos.github.api import GitHubAsyncRESTApi
 from pontos.release.command import AsyncCommand
@@ -73,9 +74,15 @@ class CreateReleaseCommand(AsyncCommand):
         terminal: A Terminal for output
     """
 
-    def __init__(self, *, terminal: Terminal, error_terminal: Terminal) -> None:
+    def __init__(
+        self,
+        *,
+        terminal: Optional[Terminal] = None,
+        error_terminal: Optional[Terminal] = None,
+        git: Optional[Git] = None,
+    ) -> None:
         super().__init__(terminal=terminal, error_terminal=error_terminal)
-        self.git = Git()
+        self.git = git or Git()
 
     def _has_tag(self, git_version: str) -> bool:
         git_tags = self.git.list_tags()
@@ -112,84 +119,25 @@ class CreateReleaseCommand(AsyncCommand):
         github = GitHubAsyncRESTApi(token=token)
 
         git_version = f"{self.git_tag_prefix}{release_version}"
-        _, project = repository_split(self.repository)
 
         await github.releases.create(
             self.repository,
             git_version,
-            name=f"{project} {release_version}",
+            name=f"{self.project_name} {release_version}",
             body=release_text,
             prerelease=release_version.is_pre_release or github_pre_release,
         )
 
-    async def async_run(  # type: ignore[override]
+    def _get_last_release_version(
         self,
         *,
-        token: str,
-        repository: str,
         versioning_scheme: VersioningScheme,
         release_type: ReleaseType,
-        release_version: Optional[Version],
-        next_version: Union[Version, Literal[False], None],
-        git_signing_key: str,
-        git_remote_name: Optional[str],
-        git_tag_prefix: Optional[str],
-        cc_config: Optional[Path],
-        local: Optional[bool] = False,
         release_series: Optional[str] = None,
-        update_project: bool = True,
-        github_pre_release: bool = False,
-    ) -> CreateReleaseReturnValue:
-        """
-        Create a release
-
-        Args:
-            token: A token for creating a release on GitHub
-            repository: GitHub repository (owner/name)
-            versioning_scheme: The versioning scheme to use for version parsing
-                and calculation
-            release_type: Type of the release to prepare. Defines the release
-                version. PATCH increments the bugfix version. CALENDAR creates
-                a new CalVer release version. VERSION uses the provided
-                release_version.
-            release_version: Optional release version to use. If not set the
-                to be released version will be determined from the project.
-            next_version: Optional version to set after the release.
-                If set to None the next development version will be set.
-                If set to False the version will not be changed after the
-                release. Default is to update to the next development version.
-            git_signing_key: A GPG key ID to use for creating signatures.
-            git_remote_name: Name of the git remote to use.
-            git_tag_prefix: An optional prefix to use for creating a git tag
-                from the release version.
-            cc_config: A path to a settings file for creating conventional
-                commits.
-            local: Only create changes locally and don't push changes to
-                remote repository. Also don't create a GitHub release.
-            release_series: Optional release series to use.
-                For example: "1.2", "2", "23".
-            update_project: Update version in project files.
-            github_pre_release: Enforce uploading a release as a GitHub pre
-                release
-        """
-        git_signing_key = (
-            git_signing_key
-            if git_signing_key is not None
-            else find_signing_key(self.terminal)
-        )
-        self.git_tag_prefix = git_tag_prefix or ""
-        self.repository = repository
-
+    ) -> Optional[Version]:
         try:
-            _, self.project_name = repository_split(repository)
-        except ValueError as e:
-            self.print_error(str(e))
-            return CreateReleaseReturnValue.INVALID_REPOSITORY
-
-        self.terminal.info(f"Using versioning scheme {versioning_scheme.name}")
-
-        try:
-            last_release_version = get_last_release_version(
+            return get_last_release_version(
+                git=self.git,
                 parse_version=versioning_scheme.parse_version,
                 git_tag_prefix=self.git_tag_prefix,
                 tag_name=(
@@ -211,20 +159,97 @@ class CreateReleaseCommand(AsyncCommand):
                 and not release_series,
             )
         except PontosError as e:
-            last_release_version = None
             self.print_warning(f"Could not determine last release version. {e}")
+            return None
+
+    async def async_run(  # type: ignore[override]
+        self,
+        *,
+        token: str,
+        repository: str,
+        versioning_scheme: VersioningScheme,
+        release_type: ReleaseType,
+        release_version: Optional[Version] = None,
+        last_release_version: Optional[Version] = None,
+        next_version: Union[Version, Literal[False], None] = None,
+        git_signing_key: Optional[str] = None,
+        git_remote_name: Optional[str] = None,
+        git_tag_prefix: Optional[str] = DEFAULT_TAG_PREFIX,
+        cc_config: Optional[Path] = None,
+        local: bool = False,
+        release_series: Optional[str] = None,
+        update_project: bool = True,
+        github_pre_release: bool = False,
+        changelog: Optional[str] = None,
+    ) -> CreateReleaseReturnValue:
+        """
+        Create a release
+
+        Args:
+            token: A token for creating a release on GitHub
+            repository: GitHub repository (owner/name)
+            versioning_scheme: The versioning scheme to use for version parsing
+                and calculation
+            release_type: Type of the release to prepare. Defines the release
+                version. PATCH increments the bugfix version. CALENDAR creates
+                a new CalVer release version. VERSION uses the provided
+                release_version.
+            release_version: Optional release version to use. If not set the
+                to be released version will be determined from the project.
+            last_release_version: Optional last release version to use. If not
+                set the last release version will be determined from the project.
+            next_version: Optional version to set after the release.
+                If set to None the next development version will be set.
+                If set to False the version will not be changed after the
+                release. Default is to update to the next development version.
+            git_signing_key: A GPG key ID to use for creating signatures.
+            git_remote_name: Name of the git remote to use.
+            git_tag_prefix: An optional prefix to use for creating a git tag
+                from the release version.
+            cc_config: A path to a settings file for creating conventional
+                commits.
+            local: Only create changes locally and don't push changes to
+                remote repository. Also don't create a GitHub release.
+            release_series: Optional release series to use.
+                For example: "1.2", "2", "23".
+            update_project: Update version in project files.
+            github_pre_release: Enforce uploading a release as a GitHub pre
+                release
+            changelog: An optional changelog. If not set a changelog will be
+                gathered from the git commits since the last release.
+        """
+        self.git_tag_prefix = git_tag_prefix or ""
+        self.repository = repository
+
+        try:
+            self.project_name = repository_split(repository)[1]
+        except (ValueError, IndexError) as e:
+            self.print_error(
+                f"Invalid repository format. Should be <owner>/<project>. Error was {e}"
+            )
+            return CreateReleaseReturnValue.INVALID_REPOSITORY
+
+        self.terminal.info(f"Using versioning scheme {versioning_scheme.name}")
 
         if not last_release_version:
-            if not release_version:
-                self.print_error("Unable to determine last release version.")
-                return CreateReleaseReturnValue.NO_LAST_RELEASE_VERSION
-            else:
-                self.terminal.info(
-                    f"Creating the initial release {release_version}"
-                )
+            last_release_version = self._get_last_release_version(
+                versioning_scheme=versioning_scheme,
+                release_type=release_type,
+                release_series=release_series,
+            )
+            if not last_release_version:
+                if not release_version:
+                    self.print_error(
+                        "Unable to determine last release version."
+                    )
+                    return CreateReleaseReturnValue.NO_LAST_RELEASE_VERSION
+                else:
+                    self.terminal.info(
+                        f"Creating the initial release {release_version}"
+                    )
 
-        else:
-            self.terminal.info(f"Last release was {last_release_version}")
+        if last_release_version:
+            self.terminal.info(f"Last release is {last_release_version}")
 
         calculator = versioning_scheme.calculator()
 
@@ -278,12 +303,21 @@ class CreateReleaseCommand(AsyncCommand):
                 f"Creating changelog for {release_version} as initial release."
             )
 
-        release_text = self._create_changelog(
-            release_version, last_release_version, cc_config
-        )
+        if changelog:
+            release_text = changelog
+        else:
+            release_text = self._create_changelog(
+                release_version, last_release_version, cc_config
+            )
 
         commit_msg = f"Automatic release to {release_version}"
 
+        git_signing_key = (
+            git_signing_key
+            if git_signing_key is not None
+            else find_signing_key(self.terminal)
+        )
+
         # check if files have been modified and create a commit
         status = list(self.git.status())
         if status:
@@ -388,6 +422,10 @@ def create_release(
         )
         return CreateReleaseReturnValue.TOKEN_MISSING
 
+    changelog_file: Path = args.changelog
+    if changelog_file and not changelog_file.exists():
+        error_terminal.error(f"Changelog file {changelog_file} does not exist.")
+        return CreateReleaseReturnValue.CREATE_RELEASE_ERROR
     return CreateReleaseCommand(
         terminal=terminal, error_terminal=error_terminal
     ).run(
@@ -396,6 +434,7 @@ def create_release(
         versioning_scheme=args.versioning_scheme,
         release_type=args.release_type,
         release_version=args.release_version,
+        last_release_version=args.last_release_version,
         next_version=args.next_version,
         git_remote_name=args.git_remote_name,
         git_signing_key=args.git_signing_key,
@@ -405,4 +444,5 @@ def create_release(
         release_series=args.release_series,
         update_project=args.update_project,
         github_pre_release=args.github_pre_release,
+        changelog=changelog_file.read_text() if changelog_file else None,
     )
