@@ -1,27 +1,14 @@
-# Copyright (C) 2020-2022 Greenbone AG
+# SPDX-FileCopyrightText: 2020-2023 Greenbone AG
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
 #
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
-#
 
 import asyncio
 import hashlib
 import subprocess
 from argparse import Namespace
 from asyncio.subprocess import Process
-from enum import IntEnum
+from enum import IntEnum, auto
 from os import PathLike
 from pathlib import Path
 from typing import AsyncContextManager, Optional, SupportsInt, Union
@@ -31,7 +18,6 @@ from rich.progress import Progress as RichProgress
 from rich.progress import TextColumn
 
 from pontos.errors import PontosError
-from pontos.git.git import GitError
 from pontos.github.api import GitHubAsyncRESTApi
 from pontos.helper import AsyncDownloadProgressIterable
 from pontos.release.command import AsyncCommand
@@ -40,7 +26,7 @@ from pontos.version import Version
 from pontos.version.helper import get_last_release_version
 from pontos.version.schemes import VersioningScheme
 
-from .helper import get_git_repository_name
+from .helper import repository_split
 
 
 class SignReturnValue(IntEnum):
@@ -49,12 +35,12 @@ class SignReturnValue(IntEnum):
     """
 
     SUCCESS = 0
-    TOKEN_MISSING = 1
-    NO_PROJECT = 2
-    NO_RELEASE_VERSION = 3
-    NO_RELEASE = 4
-    UPLOAD_ASSET_ERROR = 5
-    SIGNATURE_GENERATION_FAILED = 6
+    TOKEN_MISSING = auto()
+    NO_RELEASE_VERSION = auto()
+    NO_RELEASE = auto()
+    UPLOAD_ASSET_ERROR = auto()
+    SIGNATURE_GENERATION_FAILED = auto()
+    INVALID_REPOSITORY = auto()
 
 
 class SignatureError(PontosError):
@@ -188,12 +174,11 @@ class SignCommand(AsyncCommand):
         self,
         *,
         token: str,
-        space: str,
+        repository: str,
         versioning_scheme: VersioningScheme,
         signing_key: str,
         passphrase: str,
         dry_run: Optional[bool] = False,
-        project: Optional[str],
         git_tag_prefix: Optional[str],
         release_version: Optional[Version],
         release_series: Optional[str] = None,
@@ -203,13 +188,11 @@ class SignCommand(AsyncCommand):
 
         Args:
             token: A token for creating a release on GitHub
-            dry_run: True to not upload the signature files
-            space: GitHub username or organization. Required for generating
-                links in the changelog.
-            project: Name of the project to release. If not set it will be
-                gathered via the git remote url.
+            repository: GitHub repository (owner/name). Overrides space and
+                project.
             versioning_scheme: The versioning scheme to use for version parsing
                 and calculation
+            dry_run: True to not upload the signature files
             git_tag_prefix: An optional prefix to use for handling a git tag
                 from the release version.
             release_version: Optional release version to use. If not set the
@@ -231,12 +214,10 @@ class SignCommand(AsyncCommand):
         self.terminal.info(f"Using versioning scheme {versioning_scheme.name}")
 
         try:
-            project = (
-                project if project is not None else get_git_repository_name()
-            )
-        except GitError as e:
-            self.print_error(f"Could not determine project. {e}")
-            return SignReturnValue.NO_PROJECT
+            _, project = repository_split(repository)
+        except ValueError as e:
+            self.print_error(str(e))
+            return SignReturnValue.INVALID_REPOSITORY
 
         try:
             release_version = (
@@ -245,9 +226,11 @@ class SignCommand(AsyncCommand):
                 else get_last_release_version(
                     versioning_scheme.parse_version,
                     git_tag_prefix=git_tag_prefix,
-                    tag_name=f"{git_tag_prefix}{release_series}.*"
-                    if release_series
-                    else None,
+                    tag_name=(
+                        f"{git_tag_prefix}{release_series}.*"
+                        if release_series
+                        else None
+                    ),
                 )
             )
         except PontosError as e:
@@ -258,10 +241,9 @@ class SignCommand(AsyncCommand):
             return SignReturnValue.NO_RELEASE_VERSION
 
         git_version: str = f"{git_tag_prefix}{release_version}"
-        repo = f"{space}/{project}"
 
         async with GitHubAsyncRESTApi(token=token) as github:
-            if not await github.releases.exists(repo, git_version):
+            if not await github.releases.exists(repository, git_version):
                 self.print_error(
                     f"Release version {git_version} does not exist."
                 )
@@ -286,7 +268,7 @@ class SignCommand(AsyncCommand):
                             rich_progress,
                             github,
                             zip_destination,
-                            repo,
+                            repository,
                             git_version,
                         )
                     )
@@ -297,15 +279,18 @@ class SignCommand(AsyncCommand):
                             rich_progress,
                             github,
                             tarball_destination,
-                            repo,
+                            repository,
                             git_version,
                         )
                     )
                 )
 
                 # pylint: disable=line-too-long
-                async for name, download_cm in github.releases.download_release_assets(  # noqa: E501
-                    repo,
+                async for (
+                    name,
+                    download_cm,
+                ) in github.releases.download_release_assets(  # noqa: E501
+                    repository,
                     git_version,
                 ):
                     tasks.append(
@@ -363,8 +348,10 @@ class SignCommand(AsyncCommand):
 
             try:
                 # pylint: disable=line-too-long
-                async for uploaded_file in github.releases.upload_release_assets(  # noqa: E501
-                    repo, git_version, upload_files
+                async for (
+                    uploaded_file
+                ) in github.releases.upload_release_assets(  # noqa: E501
+                    repository, git_version, upload_files
                 ):
                     self.terminal.ok(f"Uploaded: {uploaded_file}")
             except httpx.HTTPStatusError as e:
@@ -379,14 +366,13 @@ def sign(
     *,
     terminal: Terminal,
     error_terminal: Terminal,
-    token: str,
+    token: Optional[str],
     **_kwargs,
 ) -> SupportsInt:
     return SignCommand(terminal=terminal, error_terminal=error_terminal).run(
         token=token,
         dry_run=args.dry_run,
-        project=args.project,
-        space=args.space,
+        repository=args.repository,
         versioning_scheme=args.versioning_scheme,
         git_tag_prefix=args.git_tag_prefix,
         release_version=args.release_version,
