@@ -1,19 +1,7 @@
-# Copyright (C) 2022 Greenbone AG
+# SPDX-FileCopyrightText: 2022-2023 Greenbone AG
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
 #
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 """
 A module containing classes and functions mostly useful for creating unit tests
@@ -23,9 +11,17 @@ import os
 import tempfile
 from contextlib import contextmanager
 from pathlib import Path
-from typing import Any, AsyncIterator, Awaitable, Generator, Iterable, Optional
+from typing import (
+    Any,
+    AsyncIterator,
+    Awaitable,
+    Generator,
+    Iterable,
+    Optional,
+    Union,
+)
 
-from pontos.git.git import exec_git
+from pontos.git._git import exec_git
 from pontos.helper import add_sys_path, ensure_unload_module, unload_module
 
 __all__ = (
@@ -148,7 +144,7 @@ def temp_git_repository(
 
 @contextmanager
 def temp_file(
-    content: Optional[str] = None,
+    content: Optional[Union[str, bytes]] = None,
     *,
     name: str = "test.toml",
     change_into: bool = False,
@@ -178,7 +174,10 @@ def temp_file(
     with temp_directory(change_into=change_into) as tmp_dir:
         test_file = tmp_dir / name
         if content:
-            test_file.write_text(content, encoding="utf8")
+            if isinstance(content, bytes):
+                test_file.write_bytes(content)
+            else:
+                test_file.write_text(content, encoding="utf8")
         else:
             test_file.touch()
 
@@ -217,9 +216,12 @@ def temp_python_module(
 
 
     """
-    with temp_directory(
-        add_to_sys_path=True, change_into=change_into
-    ) as tmp_dir, ensure_unload_module(name):
+    with (
+        temp_directory(
+            add_to_sys_path=True, change_into=change_into
+        ) as tmp_dir,
+        ensure_unload_module(name),
+    ):
         test_file = tmp_dir / f"{name}.py"
         test_file.write_text(content, encoding="utf8")
         yield test_file
