@@ -1,20 +1,7 @@
-# -*- coding: utf-8 -*-
-# Copyright (C) 2021-2022 Greenbone AG
+# SPDX-FileCopyrightText: 2021-2023 Greenbone AG
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
 #
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 import unittest
 from dataclasses import dataclass
@@ -86,8 +73,7 @@ class ChangelogBuilderTestCase(unittest.TestCase):
 [0.0.2]: https://github.com/foo/bar/compare/v0.0.1...v0.0.2"""
 
         changelog_builder = ChangelogBuilder(
-            space="foo",
-            project="bar",
+            repository="foo/bar",
             config=config_toml,
         )
         changelog = changelog_builder.create_changelog(
@@ -113,8 +99,7 @@ class ChangelogBuilderTestCase(unittest.TestCase):
         git_mock.return_value.log.return_value = []
 
         changelog_builder = ChangelogBuilder(
-            space="foo",
-            project="bar",
+            repository="foo/bar",
             config=config_toml,
         )
         changelog = changelog_builder.create_changelog(
@@ -175,8 +160,7 @@ class ChangelogBuilderTestCase(unittest.TestCase):
 [0.0.2]: https://github.com/foo/bar/compare/123...v0.0.2"""
 
         changelog_builder = ChangelogBuilder(
-            project="bar",
-            space="foo",
+            repository="foo/bar",
             config=config_toml,
         )
         changelog = changelog_builder.create_changelog(next_version="0.0.2")
@@ -231,8 +215,7 @@ class ChangelogBuilderTestCase(unittest.TestCase):
 [Unreleased]: https://github.com/foo/bar/compare/v0.0.1...HEAD"""
 
         changelog_builder = ChangelogBuilder(
-            project="bar",
-            space="foo",
+            repository="foo/bar",
             config=config_toml,
         )
         changelog = changelog_builder.create_changelog(last_version="0.0.1")
@@ -291,8 +274,7 @@ class ChangelogBuilderTestCase(unittest.TestCase):
 [Unreleased]: https://github.com/foo/bar/compare/123...HEAD"""
 
         changelog_builder = ChangelogBuilder(
-            project="bar",
-            space="foo",
+            repository="foo/bar",
             config=config_toml,
         )
         changelog = changelog_builder.create_changelog()
@@ -319,8 +301,7 @@ class ChangelogBuilderTestCase(unittest.TestCase):
             "8abcdef bar baz",
         ]
         changelog_builder = ChangelogBuilder(
-            space="foo",
-            project="bar",
+            repository="foo/bar",
             config=config_toml,
         )
         changelog = changelog_builder.create_changelog(
@@ -334,13 +315,15 @@ class ChangelogBuilderTestCase(unittest.TestCase):
         )
 
     def test_changelog_builder_config_file_not_exists(self):
-        with temp_directory() as temp_dir, self.assertRaisesRegex(
-            ChangelogBuilderError,
-            r"Changelog Config file '.*\.toml' does not exist\.",
+        with (
+            temp_directory() as temp_dir,
+            self.assertRaisesRegex(
+                ChangelogBuilderError,
+                r"Changelog Config file '.*\.toml' does not exist\.",
+            ),
         ):
             ChangelogBuilder(
-                space="foo",
-                project="bar",
+                repository="foo/bar",
                 config=temp_dir / "changelog.toml",
             )
 
@@ -365,8 +348,7 @@ class ChangelogBuilderTestCase(unittest.TestCase):
         ]
 
         changelog_builder = ChangelogBuilder(
-            space="foo",
-            project="bar",
+            repository="foo/bar",
         )
         expected_output = f"""## [0.0.2] - {today}
 
@@ -417,8 +399,7 @@ class ChangelogBuilderTestCase(unittest.TestCase):
         ]
 
         changelog_builder = ChangelogBuilder(
-            space="foo",
-            project="bar",
+            repository="foo/bar",
             git_tag_prefix="",
         )
         expected_output = f"""## [0.0.2] - {today}
@@ -495,7 +476,8 @@ class ChangelogBuilderTestCase(unittest.TestCase):
 [0.0.2]: https://github.com/foo/bar/compare/v0.0.1...v0.0.2"""
 
         changelog_builder = ChangelogBuilder(
-            space="foo", project="bar", config=config_toml
+            repository="foo/bar",
+            config=config_toml,
         )
 
         with temp_directory() as temp_dir:
