@@ -1,45 +1,34 @@
-# Copyright (C) 2022 Greenbone AG
+# SPDX-FileCopyrightText: 2022-2023 Greenbone AG
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
 #
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 import unittest
 from pathlib import Path
 from unittest.mock import MagicMock, patch
 
-from pontos.git import Git
-from pontos.git.git import (
+from pontos.git import (
     DEFAULT_TAG_SORT_SUFFIX,
     ConfigScope,
+    Git,
     GitError,
     MergeStrategy,
+    ResetMode,
+    Status,
     TagSort,
 )
-from pontos.git.status import Status
 from pontos.testing import temp_directory, temp_git_repository
 
 
 class GitTestCase(unittest.TestCase):
-    @patch("pontos.git.git.exec_git")
+    @patch("pontos.git._git.exec_git")
     def test_exec(self, exec_git_mock):
         git = Git()
         git.exec("foo", "bar", "baz")
 
         exec_git_mock.assert_called_once_with("foo", "bar", "baz", cwd=None)
 
-    @patch("pontos.git.git.exec_git")
+    @patch("pontos.git._git.exec_git")
     def test_clone(self, exec_git_mock):
         git = Git()
         git.clone("http://foo/foo.git", Path("/bar"))
@@ -48,7 +37,7 @@ class GitTestCase(unittest.TestCase):
             "clone", "http://foo/foo.git", "/bar", cwd=None
         )
 
-    @patch("pontos.git.git.exec_git")
+    @patch("pontos.git._git.exec_git")
     def test_clone_with_remote(self, exec_git_mock):
         git = Git()
         git.clone("http://foo/foo.git", Path("/bar"), remote="foo")
@@ -57,7 +46,7 @@ class GitTestCase(unittest.TestCase):
             "clone", "-o", "foo", "http://foo/foo.git", "/bar", cwd=None
         )
 
-    @patch("pontos.git.git.exec_git")
+    @patch("pontos.git._git.exec_git")
     def test_clone_with_branch(self, exec_git_mock):
         git = Git()
         git.clone("http://foo/foo.git", Path("/bar"), branch="foo")
@@ -66,7 +55,7 @@ class GitTestCase(unittest.TestCase):
             "clone", "-b", "foo", "http://foo/foo.git", "/bar", cwd=None
         )
 
-    @patch("pontos.git.git.exec_git")
+    @patch("pontos.git._git.exec_git")
     def test_clone_with_depth(self, exec_git_mock):
         git = Git()
         git.clone("http://foo/foo.git", Path("/bar"), depth=1)
@@ -75,14 +64,14 @@ class GitTestCase(unittest.TestCase):
             "clone", "--depth", "1", "http://foo/foo.git", "/bar", cwd=None
         )
 
-    @patch("pontos.git.git.exec_git")
+    @patch("pontos.git._git.exec_git")
     def test_init(self, exec_git_mock):
         git = Git()
         git.init()
 
         exec_git_mock.assert_called_once_with("init", cwd=None)
 
-    @patch("pontos.git.git.exec_git")
+    @patch("pontos.git._git.exec_git")
     def test_init_bare(self, exec_git_mock):
         git = Git()
         git.init(bare=True)
@@ -99,14 +88,14 @@ class GitTestCase(unittest.TestCase):
 
         self.assertEqual(git.cwd, new_cwd.absolute())
 
-    @patch("pontos.git.git.exec_git")
+    @patch("pontos.git._git.exec_git")
     def test_create_branch(self, exec_git_mock):
         git = Git()
         git.create_branch("foo")
 
         exec_git_mock.assert_called_once_with("checkout", "-b", "foo", cwd=None)
 
-    @patch("pontos.git.git.exec_git")
+    @patch("pontos.git._git.exec_git")
     def test_create_branch_with_starting_point(self, exec_git_mock):
         git = Git()
         git.create_branch("foo", start_point="bar")
@@ -115,21 +104,21 @@ class GitTestCase(unittest.TestCase):
             "checkout", "-b", "foo", "bar", cwd=None
         )
 
-    @patch("pontos.git.git.exec_git")
+    @patch("pontos.git._git.exec_git")
     def test_rebase(self, exec_git_mock):
         git = Git()
         git.rebase("foo")
 
         exec_git_mock.assert_called_once_with("rebase", "foo", cwd=None)
 
-    @patch("pontos.git.git.exec_git")
+    @patch("pontos.git._git.exec_git")
     def test_rebase_with_head(self, exec_git_mock):
         git = Git()
         git.rebase("foo", head="bar")
 
         exec_git_mock.assert_called_once_with("rebase", "foo", "bar", cwd=None)
 
-    @patch("pontos.git.git.exec_git")
+    @patch("pontos.git._git.exec_git")
     def test_rebase_with_head_and_onto(self, exec_git_mock):
         git = Git()
         git.rebase("foo", head="bar", onto="staging")
@@ -138,7 +127,7 @@ class GitTestCase(unittest.TestCase):
             "rebase", "--onto", "staging", "foo", "bar", cwd=None
         )
 
-    @patch("pontos.git.git.exec_git")
+    @patch("pontos.git._git.exec_git")
     def test_rebase_with_octopus_strategy(self, exec_git_mock):
         git = Git()
         git.rebase("foo", strategy=MergeStrategy.OCTOPUS)
@@ -147,7 +136,7 @@ class GitTestCase(unittest.TestCase):
             "rebase", "--strategy", "octopus", "foo", cwd=None
         )
 
-    @patch("pontos.git.git.exec_git")
+    @patch("pontos.git._git.exec_git")
     def test_rebase_with_ort_ours_strategy(self, exec_git_mock):
         git = Git()
         git.rebase("foo", strategy=MergeStrategy.ORT_OURS)
@@ -156,70 +145,104 @@ class GitTestCase(unittest.TestCase):
             "rebase", "--strategy", "ort", "-X", "ours", "foo", cwd=None
         )
 
-    @patch("pontos.git.git.exec_git")
+    @patch("pontos.git._git.exec_git")
     def test_push(self, exec_git_mock):
         git = Git()
         git.push()
 
         exec_git_mock.assert_called_once_with("push", cwd=None)
 
-    @patch("pontos.git.git.exec_git")
+    @patch("pontos.git._git.exec_git")
     def test_push_with_remote(self, exec_git_mock):
         git = Git()
         git.push(remote="foo")
 
         exec_git_mock.assert_called_once_with("push", "foo", cwd=None)
 
-    @patch("pontos.git.git.exec_git")
+    @patch("pontos.git._git.exec_git")
     def test_push_with_remote_and_branch(self, exec_git_mock):
         git = Git()
         git.push(remote="foo", branch="bar")
 
         exec_git_mock.assert_called_once_with("push", "foo", "bar", cwd=None)
 
-    @patch("pontos.git.git.exec_git")
+    @patch("pontos.git._git.exec_git")
     def test_push_with_follow_tags(self, exec_git_mock):
         git = Git()
         git.push(follow_tags=True)
 
         exec_git_mock.assert_called_once_with("push", "--follow-tags", cwd=None)
 
-    @patch("pontos.git.git.exec_git")
+    @patch("pontos.git._git.exec_git")
     def test_push_with_follow_tags_false(self, exec_git_mock):
         git = Git()
         git.push(follow_tags=False)
 
         exec_git_mock.assert_called_once_with("push", cwd=None)
 
-    @patch("pontos.git.git.exec_git")
+    @patch("pontos.git._git.exec_git")
     def test_push_with_force(self, exec_git_mock):
         git = Git()
         git.push(force=True)
 
         exec_git_mock.assert_called_once_with("push", "--force", cwd=None)
 
-    @patch("pontos.git.git.exec_git")
+    @patch("pontos.git._git.exec_git")
     def test_push_with_force_false(self, exec_git_mock):
         git = Git()
         git.push(force=False)
 
         exec_git_mock.assert_called_once_with("push", cwd=None)
 
-    @patch("pontos.git.git.exec_git")
+    @patch("pontos.git._git.exec_git")
+    def test_push_branch_with_delete(self, exec_git_mock):
+        git = Git()
+        git.push(delete=True, branch="v1.2.3", remote="origin")
+
+        exec_git_mock.assert_called_once_with(
+            "push", "--delete", "origin", "v1.2.3", cwd=None
+        )
+
+    @patch("pontos.git._git.exec_git")
+    def test_push_refspec_with_delete(self, exec_git_mock):
+        git = Git()
+        git.push("v1.2.3", delete=True)
+
+        exec_git_mock.assert_called_once_with(
+            "push", "--delete", "v1.2.3", cwd=None
+        )
+
+    @patch("pontos.git._git.exec_git")
+    def test_push_refspec(self, exec_git_mock):
+        git = Git()
+        git.push("v1.2.3")
+
+        exec_git_mock.assert_called_once_with("push", "v1.2.3", cwd=None)
+
+    @patch("pontos.git._git.exec_git")
+    def test_push_refspecs(self, exec_git_mock):
+        git = Git()
+        git.push(["v1.2.3", "main"])
+
+        exec_git_mock.assert_called_once_with(
+            "push", "v1.2.3", "main", cwd=None
+        )
+
+    @patch("pontos.git._git.exec_git")
     def test_config_get(self, exec_git_mock):
         git = Git()
         git.config("foo")
 
         exec_git_mock.assert_called_once_with("config", "foo", cwd=None)
 
-    @patch("pontos.git.git.exec_git")
+    @patch("pontos.git._git.exec_git")
     def test_config_set(self, exec_git_mock):
         git = Git()
         git.config("foo", "bar")
 
         exec_git_mock.assert_called_once_with("config", "foo", "bar", cwd=None)
 
-    @patch("pontos.git.git.exec_git")
+    @patch("pontos.git._git.exec_git")
     def test_config_get_local_scope(self, exec_git_mock):
         git = Git()
         git.config("foo", scope=ConfigScope.LOCAL)
@@ -228,7 +251,7 @@ class GitTestCase(unittest.TestCase):
             "config", "--local", "foo", cwd=None
         )
 
-    @patch("pontos.git.git.exec_git")
+    @patch("pontos.git._git.exec_git")
     def test_config_get_system_scope(self, exec_git_mock):
         git = Git()
         git.config("foo", scope=ConfigScope.SYSTEM)
@@ -237,7 +260,7 @@ class GitTestCase(unittest.TestCase):
             "config", "--system", "foo", cwd=None
         )
 
-    @patch("pontos.git.git.exec_git")
+    @patch("pontos.git._git.exec_git")
     def test_config_get_global_scope(self, exec_git_mock):
         git = Git()
         git.config("foo", scope=ConfigScope.GLOBAL)
@@ -246,7 +269,7 @@ class GitTestCase(unittest.TestCase):
             "config", "--global", "foo", cwd=None
         )
 
-    @patch("pontos.git.git.exec_git")
+    @patch("pontos.git._git.exec_git")
     def test_config_get_worktree_scope(self, exec_git_mock):
         git = Git()
         git.config("foo", scope=ConfigScope.WORKTREE)
@@ -255,7 +278,7 @@ class GitTestCase(unittest.TestCase):
             "config", "--worktree", "foo", cwd=None
         )
 
-    @patch("pontos.git.git.exec_git")
+    @patch("pontos.git._git.exec_git")
     def test_cherry_pick(self, exec_git_mock):
         git = Git()
         git.cherry_pick(["foo", "bar"])
@@ -264,14 +287,14 @@ class GitTestCase(unittest.TestCase):
             "cherry-pick", "foo", "bar", cwd=None
         )
 
-    @patch("pontos.git.git.exec_git")
+    @patch("pontos.git._git.exec_git")
     def test_cherry_pick_single_commit(self, exec_git_mock):
         git = Git()
         git.cherry_pick("foo")
 
         exec_git_mock.assert_called_once_with("cherry-pick", "foo", cwd=None)
 
-    @patch("pontos.git.git.exec_git")
+    @patch("pontos.git._git.exec_git")
     def test_list_tags(self, exec_git_mock):
         exec_git_mock.return_value = "v1.0\nv2.0\nv2.1\n"
         git = Git()
@@ -284,7 +307,7 @@ class GitTestCase(unittest.TestCase):
         self.assertEqual(tags[1], "v2.0")
         self.assertEqual(tags[2], "v2.1")
 
-    @patch("pontos.git.git.exec_git")
+    @patch("pontos.git._git.exec_git")
     def test_list_tags_with_version_sort(self, exec_git_mock):
         exec_git_mock.return_value = "v1.0\nv2.0\nv2.1\n"
         git = Git()
@@ -302,7 +325,7 @@ class GitTestCase(unittest.TestCase):
         self.assertEqual(tags[1], "v2.0")
         self.assertEqual(tags[2], "v2.1")
 
-    @patch("pontos.git.git.exec_git")
+    @patch("pontos.git._git.exec_git")
     def test_list_tags_with_version_suffix_sort(self, exec_git_mock):
         exec_git_mock.return_value = "v1.0\nv2.0\nv2.1\n"
         git = Git()
@@ -334,7 +357,7 @@ class GitTestCase(unittest.TestCase):
         self.assertEqual(tags[1], "v2.0")
         self.assertEqual(tags[2], "v2.1")
 
-    @patch("pontos.git.git.exec_git")
+    @patch("pontos.git._git.exec_git")
     def test_list_tags_with_tag_name(self, exec_git_mock):
         exec_git_mock.return_value = "v2.0\nv2.1\n"
         git = Git()
@@ -346,21 +369,21 @@ class GitTestCase(unittest.TestCase):
         self.assertEqual(tags[0], "v2.0")
         self.assertEqual(tags[1], "v2.1")
 
-    @patch("pontos.git.git.exec_git")
+    @patch("pontos.git._git.exec_git")
     def test_add_single_file(self, exec_git_mock):
         git = Git()
         git.add("foo")
 
         exec_git_mock.assert_called_once_with("add", "foo", cwd=None)
 
-    @patch("pontos.git.git.exec_git")
+    @patch("pontos.git._git.exec_git")
     def test_add(self, exec_git_mock):
         git = Git()
         git.add(["foo", "bar"])
 
         exec_git_mock.assert_called_once_with("add", "foo", "bar", cwd=None)
 
-    @patch("pontos.git.git.exec_git")
+    @patch("pontos.git._git.exec_git")
     def test_commit(self, exec_git_mock):
         git = Git()
         git.commit("Add foo")
@@ -369,7 +392,7 @@ class GitTestCase(unittest.TestCase):
             "commit", "-m", "Add foo", cwd=None
         )
 
-    @patch("pontos.git.git.exec_git")
+    @patch("pontos.git._git.exec_git")
     def test_commit_with_signing_key(self, exec_git_mock):
         git = Git()
         git.commit(
@@ -385,7 +408,7 @@ class GitTestCase(unittest.TestCase):
             cwd=None,
         )
 
-    @patch("pontos.git.git.exec_git")
+    @patch("pontos.git._git.exec_git")
     def test_commit_without_verify(self, exec_git_mock):
         git = Git()
         git.commit("Add foo", verify=False)
@@ -394,7 +417,7 @@ class GitTestCase(unittest.TestCase):
             "commit", "--no-verify", "-m", "Add foo", cwd=None
         )
 
-    @patch("pontos.git.git.exec_git")
+    @patch("pontos.git._git.exec_git")
     def test_commit_without_gpg_sign(self, exec_git_mock):
         git = Git()
         git.commit("Add foo", gpg_sign=False)
@@ -403,14 +426,14 @@ class GitTestCase(unittest.TestCase):
             "commit", "--no-gpg-sign", "-m", "Add foo", cwd=None
         )
 
-    @patch("pontos.git.git.exec_git")
+    @patch("pontos.git._git.exec_git")
     def test_tag(self, exec_git_mock):
         git = Git()
         git.tag(tag="test")
 
         exec_git_mock.assert_called_once_with("tag", "test", cwd=None)
 
-    @patch("pontos.git.git.exec_git")
+    @patch("pontos.git._git.exec_git")
     def test_tag_with_gpg_key(self, exec_git_mock):
         git = Git()
         git.tag("test", gpg_key_id="0x123")
@@ -419,7 +442,7 @@ class GitTestCase(unittest.TestCase):
             "tag", "-u", "0x123", "test", cwd=None
         )
 
-    @patch("pontos.git.git.exec_git")
+    @patch("pontos.git._git.exec_git")
     def test_tag_with_message(self, exec_git_mock):
         git = Git()
         git.tag("test", message="Tag for 123 release")
@@ -428,7 +451,7 @@ class GitTestCase(unittest.TestCase):
             "tag", "-m", "Tag for 123 release", "test", cwd=None
         )
 
-    @patch("pontos.git.git.exec_git")
+    @patch("pontos.git._git.exec_git")
     def test_tag_with_force(self, exec_git_mock):
         git = Git()
         git.tag("test", force=True)
@@ -437,7 +460,7 @@ class GitTestCase(unittest.TestCase):
             "tag", "--force", "test", cwd=None
         )
 
-    @patch("pontos.git.git.exec_git")
+    @patch("pontos.git._git.exec_git")
     def test_tag_without_sign(self, exec_git_mock):
         git = Git()
         git.tag("test", sign=False)
@@ -446,21 +469,21 @@ class GitTestCase(unittest.TestCase):
             "tag", "--no-sign", "test", cwd=None
         )
 
-    @patch("pontos.git.git.exec_git")
+    @patch("pontos.git._git.exec_git")
     def test_fetch(self, exec_git_mock):
         git = Git()
         git.fetch()
 
         exec_git_mock.assert_called_once_with("fetch", cwd=None)
 
-    @patch("pontos.git.git.exec_git")
+    @patch("pontos.git._git.exec_git")
     def test_fetch_with_remote(self, exec_git_mock):
         git = Git()
         git.fetch("foo")
 
         exec_git_mock.assert_called_once_with("fetch", "foo", cwd=None)
 
-    @patch("pontos.git.git.exec_git")
+    @patch("pontos.git._git.exec_git")
     def test_fetch_with_remote_and_refspec(self, exec_git_mock):
         git = Git()
         git.fetch("foo", "my-branch")
@@ -469,14 +492,14 @@ class GitTestCase(unittest.TestCase):
             "fetch", "foo", "my-branch", cwd=None
         )
 
-    @patch("pontos.git.git.exec_git")
+    @patch("pontos.git._git.exec_git")
     def test_fetch_with_verbose(self, exec_git_mock):
         git = Git()
         git.fetch(verbose=True)
 
         exec_git_mock.assert_called_once_with("fetch", "-v", cwd=None)
 
-    @patch("pontos.git.git.exec_git")
+    @patch("pontos.git._git.exec_git")
     def test_add_remote(self, exec_git_mock):
         git = Git()
         git.add_remote("foo", "https://foo.bar/foo.git")
@@ -485,14 +508,14 @@ class GitTestCase(unittest.TestCase):
             "remote", "add", "foo", "https://foo.bar/foo.git", cwd=None
         )
 
-    @patch("pontos.git.git.exec_git")
+    @patch("pontos.git._git.exec_git")
     def test_checkout(self, exec_git_mock):
         git = Git()
         git.checkout("foo")
 
         exec_git_mock.assert_called_once_with("checkout", "foo", cwd=None)
 
-    @patch("pontos.git.git.exec_git")
+    @patch("pontos.git._git.exec_git")
     def test_checkout_with_start_point(self, exec_git_mock):
         git = Git()
         git.checkout("foo", start_point="bar")
@@ -501,7 +524,7 @@ class GitTestCase(unittest.TestCase):
             "checkout", "-b", "foo", "bar", cwd=None
         )
 
-    @patch("pontos.git.git.exec_git")
+    @patch("pontos.git._git.exec_git")
     def test_remote_url(self, exec_git_mock):
         url = "git@github.com:foo/foo.git"
         exec_git_mock.return_value = url
@@ -515,7 +538,7 @@ class GitTestCase(unittest.TestCase):
 
         self.assertEqual(remote, url)
 
-    @patch("pontos.git.git.exec_git")
+    @patch("pontos.git._git.exec_git")
     def test_remote_url_with_default(self, exec_git_mock):
         url = "git@github.com:foo/foo.git"
         exec_git_mock.return_value = url
@@ -529,7 +552,7 @@ class GitTestCase(unittest.TestCase):
 
         self.assertEqual(remote, url)
 
-    @patch("pontos.git.git.exec_git")
+    @patch("pontos.git._git.exec_git")
     def test_log(self, exec_git_mock):
         # pylint: disable=line-too-long
         exec_git_mock.return_value = """commit 68c6c3785bbb049df63dc51f8b5b709eb19f8517
@@ -557,7 +580,7 @@ Date:   Wed Apr 8 14:28:53 2020 +0200
             logs[6], "commit 464f24d43d7293091b168c6b37ee37978a650958"
         )
 
-    @patch("pontos.git.git.exec_git")
+    @patch("pontos.git._git.exec_git")
     def test_log_with_oneline(self, exec_git_mock):
         exec_git_mock.return_value = """50f9963 Add CircleCI config for pontos
 9a8feaa Rename to pontos only
@@ -574,7 +597,7 @@ e6ea80d Update README
         self.assertEqual(logs[0], "50f9963 Add CircleCI config for pontos")
         self.assertEqual(logs[5], "464f24d Initial commit")
 
-    @patch("pontos.git.git.exec_git")
+    @patch("pontos.git._git.exec_git")
     def test_log_with_format(self, exec_git_mock):
         exec_git_mock.return_value = """Add CircleCI config for pontos
 Rename to pontos only
@@ -593,7 +616,7 @@ Initial commit"""
         self.assertEqual(logs[0], "Add CircleCI config for pontos")
         self.assertEqual(logs[5], "Initial commit")
 
-    @patch("pontos.git.git.exec_git")
+    @patch("pontos.git._git.exec_git")
     def test_rev_list(self, exec_git_mock):
         git = Git()
         git.rev_list("foo", "bar", "baz", max_parents=123, abbrev_commit=True)
@@ -608,7 +631,7 @@ Initial commit"""
             cwd=None,
         )
 
-    @patch("pontos.git.git.exec_git")
+    @patch("pontos.git._git.exec_git")
     def test_move(self, exec_git_mock):
         git = Git()
         git.move("foo", "bar")
@@ -620,7 +643,7 @@ Initial commit"""
             cwd=None,
         )
 
-    @patch("pontos.git.git.exec_git")
+    @patch("pontos.git._git.exec_git")
     def test_remove(self, exec_git_mock):
         git = Git()
         git.remove("foo")
@@ -631,7 +654,7 @@ Initial commit"""
             cwd=None,
         )
 
-    @patch("pontos.git.git.exec_git")
+    @patch("pontos.git._git.exec_git")
     def test_status(self, exec_git_mock):
         git = Git()
         git.status()
@@ -644,7 +667,7 @@ Initial commit"""
             cwd=None,
         )
 
-    @patch("pontos.git.git.exec_git")
+    @patch("pontos.git._git.exec_git")
     def test_status_with_files(self, exec_git_mock):
         git = Git()
         git.status(["foo", "bar", "baz"])
@@ -661,7 +684,7 @@ Initial commit"""
             cwd=None,
         )
 
-    @patch("pontos.git.git.exec_git")
+    @patch("pontos.git._git.exec_git")
     def test_version(self, exec_git_mock: MagicMock):
         exec_git_mock.return_value = "git version 1.2.3"
         git = Git()
@@ -672,7 +695,7 @@ Initial commit"""
         git = Git()
         git.version
 
-    @patch("pontos.git.git.exec_git")
+    @patch("pontos.git._git.exec_git")
     def test_show_with_online_and_objects(self, exec_git_mock: MagicMock):
         exec_git_mock.return_value = """9a8feaa Rename to pontos only
 047cfae Update README for installation and development
@@ -690,7 +713,7 @@ Initial commit"""
             show[1], "047cfae Update README for installation and development"
         )
 
-    @patch("pontos.git.git.exec_git")
+    @patch("pontos.git._git.exec_git")
     def test_show_with_format(self, exec_git_mock: MagicMock):
         exec_git_mock.return_value = """Rename to pontos only
 """
@@ -704,7 +727,7 @@ Initial commit"""
 
         self.assertEqual(show, "Rename to pontos only")
 
-    @patch("pontos.git.git.exec_git")
+    @patch("pontos.git._git.exec_git")
     def test_show_with_single_object(self, exec_git_mock: MagicMock):
         content = """commit a6956fb1398cae9426e7ced0396248a90dc1ff64
 Author: Björn Ricks <bjoern.ricks@greenbone.net>
@@ -712,10 +735,10 @@ Date:   Wed Jul 19 15:07:03 2023 +0200
 
     Add: Allow to get the git version string
 
-diff --git a/pontos/git/git.py b/pontos/git/git.py
+diff --git a/pontos.git._git.py b/pontos.git._git.py
 index a83eed8..09aed3d 100644
---- a/pontos/git/git.py
-+++ b/pontos/git/git.py
+--- a/pontos.git._git.py
++++ b/pontos.git._git.py
 @@ -168,6 +168,14 @@ class Git:
 ...
 """
@@ -728,7 +751,7 @@ index a83eed8..09aed3d 100644
 
         self.assertEqual(show, content.strip())
 
-    @patch("pontos.git.git.exec_git")
+    @patch("pontos.git._git.exec_git")
     def test_show_with_patch(self, exec_git_mock: MagicMock):
         content = """commit a6956fb1398cae9426e7ced0396248a90dc1ff64
 Author: Björn Ricks <bjoern.ricks@greenbone.net>
@@ -736,10 +759,10 @@ Date:   Wed Jul 19 15:07:03 2023 +0200
 
     Add: Allow to get the git version string
 
-diff --git a/pontos/git/git.py b/pontos/git/git.py
+diff --git a/pontos.git._git.py b/pontos.git._git.py
 index a83eed8..09aed3d 100644
---- a/pontos/git/git.py
-+++ b/pontos/git/git.py
+--- a/pontos.git._git.py
++++ b/pontos.git._git.py
 @@ -168,6 +168,14 @@ class Git:
 ...
 """
@@ -752,7 +775,7 @@ index a83eed8..09aed3d 100644
 
         self.assertEqual(show, content.strip())
 
-    @patch("pontos.git.git.exec_git")
+    @patch("pontos.git._git.exec_git")
     def test_show_with_no_patch(self, exec_git_mock: MagicMock):
         content = """commit a6956fb1398cae9426e7ced0396248a90dc1ff64
 Author: Björn Ricks <bjoern.ricks@greenbone.net>
@@ -769,6 +792,22 @@ Date:   Wed Jul 19 15:07:03 2023 +0200
 
         self.assertEqual(show, content.strip())
 
+    @patch("pontos.git._git.exec_git")
+    def test_delete_tag(self, exec_git_mock):
+        git = Git()
+        git.delete_tag("v1.2.3")
+
+        exec_git_mock.assert_called_once_with("tag", "-d", "v1.2.3", cwd=None)
+
+    @patch("pontos.git._git.exec_git")
+    def test_reset_mixed(self, exec_git_mock):
+        git = Git()
+        git.reset("c1234", mode=ResetMode.MIXED)
+
+        exec_git_mock.assert_called_once_with(
+            "reset", "--mixed", "c1234", cwd=None
+        )
+
 
 class GitExtendedTestCase(unittest.TestCase):
     def test_semantic_list_tags(self):
@@ -1056,9 +1095,10 @@ class GitExtendedTestCase(unittest.TestCase):
                 next(it)
 
     def test_git_error(self):
-        with temp_directory(change_into=True), self.assertRaises(
-            GitError
-        ) as cm:
+        with (
+            temp_directory(change_into=True),
+            self.assertRaises(GitError) as cm,
+        ):
             Git().log()
 
         self.assertEqual(cm.exception.returncode, 128)
