@@ -1,19 +1,7 @@
-# Copyright (C) 2020-2022 Greenbone AG
+# SPDX-FileCopyrightText: 2020-2023 Greenbone AG
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
 #
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 # pylint: disable=C0413,W0108
 
 import unittest
@@ -40,8 +28,8 @@ class SignTestCase(unittest.TestCase):
         _, token, args = parse_args(
             [
                 "sign",
-                "--project",
-                "foo",
+                "--repository",
+                "greenbone/foo",
                 "--release-version",
                 "0.0.1",
             ]
@@ -56,30 +44,13 @@ class SignTestCase(unittest.TestCase):
 
         self.assertEqual(result, SignReturnValue.TOKEN_MISSING)
 
-    def test_no_project(self):
-        with temp_directory(change_into=True):
-            _, token, args = parse_args(
-                [
-                    "sign",
-                ]
-            )
-
-            result = sign(
-                terminal=mock_terminal(),
-                error_terminal=mock_terminal(),
-                args=args,
-                token=token,
-            )
-
-            self.assertEqual(result, SignReturnValue.NO_PROJECT)
-
     def test_no_release_error(self):
         with temp_directory(change_into=True):
             _, token, args = parse_args(
                 [
                     "sign",
-                    "--project",
-                    "foo",
+                    "--repository",
+                    "greenbone/foo",
                 ]
             )
 
@@ -92,6 +63,27 @@ class SignTestCase(unittest.TestCase):
 
             self.assertEqual(result, SignReturnValue.NO_RELEASE_VERSION)
 
+    def test_invalid_repository(self):
+        with temp_directory(change_into=True):
+            _, token, args = parse_args(
+                [
+                    "sign",
+                    "--repository",
+                    "foo/bar",
+                ]
+            )
+
+            setattr(args, "repository", "foo_bar")
+
+            result = sign(
+                terminal=mock_terminal(),
+                error_terminal=mock_terminal(),
+                args=args,
+                token=token,
+            )
+
+            self.assertEqual(result, SignReturnValue.INVALID_REPOSITORY)
+
     @patch("pontos.release.sign.get_last_release_version", autospec=True)
     def test_no_release_version(self, get_last_release_version_mock: MagicMock):
         get_last_release_version_mock.return_value = None
@@ -100,8 +92,8 @@ class SignTestCase(unittest.TestCase):
             _, token, args = parse_args(
                 [
                     "sign",
-                    "--project",
-                    "foo",
+                    "--repository",
+                    "foo/bar",
                 ]
             )
 
@@ -122,8 +114,8 @@ class SignTestCase(unittest.TestCase):
             _, token, args = parse_args(
                 [
                     "sign",
-                    "--project",
-                    "foo",
+                    "--repository",
+                    "foo/bar",
                     "--release-version",
                     "1.2.3",
                 ]
@@ -178,8 +170,8 @@ class SignTestCase(unittest.TestCase):
             _, token, args = parse_args(
                 [
                     "sign",
-                    "--project",
-                    "foo",
+                    "--repository",
+                    "greenbone/foo",
                     "--release-version",
                     "1.2.3",
                 ]
@@ -289,8 +281,8 @@ class SignTestCase(unittest.TestCase):
             _, token, args = parse_args(
                 [
                     "sign",
-                    "--project",
-                    "foo",
+                    "--repository",
+                    "greenbone/foo",
                 ]
             )
 
@@ -398,7 +390,13 @@ class SignTestCase(unittest.TestCase):
 
         with temp_directory(change_into=True):
             _, token, args = parse_args(
-                ["sign", "--project", "foo", "--release-series", "2"]
+                [
+                    "sign",
+                    "--repository",
+                    "greenbone/foo",
+                    "--release-series",
+                    "2",
+                ]
             )
 
             result = sign(
@@ -502,8 +500,8 @@ class SignTestCase(unittest.TestCase):
             _, token, args = parse_args(
                 [
                     "sign",
-                    "--project",
-                    "foo",
+                    "--repository",
+                    "greenbone/foo",
                     "--release-version",
                     "1.2.3",
                     "--dry-run",
@@ -602,8 +600,8 @@ class SignTestCase(unittest.TestCase):
             _, token, args = parse_args(
                 [
                     "sign",
-                    "--project",
-                    "foo",
+                    "--repository",
+                    "greenbone/foo",
                     "--release-version",
                     "1.2.3",
                 ]
@@ -683,8 +681,8 @@ class SignTestCase(unittest.TestCase):
             _, token, args = parse_args(
                 [
                     "sign",
-                    "--project",
-                    "foo",
+                    "--repository",
+                    "greenbone/foo",
                     "--release-version",
                     "1.2.3",
                 ]
