@@ -1,19 +1,7 @@
-# Copyright (C) 2022 Greenbone AG
+# SPDX-FileCopyrightText: 2022-2023 Greenbone AG
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
 #
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 # pylint: disable=redefined-builtin,disallowed-name
 # ruff: noqa: E501
@@ -515,8 +503,9 @@ class AddSysPathTestCase(unittest.TestCase):
             # pylint: disable=import-error,import-outside-toplevel,unused-import
             import mymodule  # noqa: F811,F401
 
-        with temp_file("", name="mymodule.py") as module_path, add_sys_path(
-            module_path.parent
+        with (
+            temp_file("", name="mymodule.py") as module_path,
+            add_sys_path(module_path.parent),
         ):
             # pylint: disable=import-error,import-outside-toplevel,unused-import
             import mymodule  # noqa: F811,F401
@@ -526,9 +515,10 @@ class AddSysPathTestCase(unittest.TestCase):
 
 class EnsureUnloadModuleTestCase(unittest.TestCase):
     def test_ensure_unload_module(self):
-        with temp_python_module(
-            "def foo():\n  pass", name="bar"
-        ), ensure_unload_module("bar"):
+        with (
+            temp_python_module("def foo():\n  pass", name="bar"),
+            ensure_unload_module("bar"),
+        ):
             # pylint: disable=import-error,import-outside-toplevel,unused-import
             import bar  # noqa: F401,F811
 
@@ -538,9 +528,12 @@ class EnsureUnloadModuleTestCase(unittest.TestCase):
 
     def test_ensure_unload_module_exception(self):
         with self.assertRaisesRegex(ValueError, "Ipsum"):
-            with temp_python_module(
-                "def func():\n  raise ValueError('Ipsum')", name="bar"
-            ), ensure_unload_module("bar"):
+            with (
+                temp_python_module(
+                    "def func():\n  raise ValueError('Ipsum')", name="bar"
+                ),
+                ensure_unload_module("bar"),
+            ):
                 # pylint: disable=import-error,import-outside-toplevel,unused-import
                 import bar
 
@@ -556,8 +549,9 @@ class EnsureUnloadModuleTestCase(unittest.TestCase):
             import mymodule  # noqa: F811,F401
 
         try:
-            with temp_file("", name="mymodule.py") as module_path, add_sys_path(
-                module_path.parent
+            with (
+                temp_file("", name="mymodule.py") as module_path,
+                add_sys_path(module_path.parent),
             ):
                 # pylint: disable=import-error,import-outside-toplevel,unused-import
                 import mymodule  # noqa: F811,F401
