@@ -1,24 +1,13 @@
-# Copyright (C) 2022 Greenbone AG
+# SPDX-FileCopyrightText: 2022-2023 Greenbone AG
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
 #
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
+import struct
 import unittest
 from pathlib import Path
 
-from pontos.git.git import Git
+from pontos.git import Git
 from pontos.helper import unload_module
 from pontos.testing import (
     temp_directory,
@@ -121,6 +110,14 @@ class TempFileTestCase(unittest.TestCase):
 
         self.assertFalse(test_file.exists())
 
+    def test_temp_binary_file(self):
+        data = struct.pack(">if", 42, 2.71828182846)
+        with temp_file(data) as test_file:
+            self.assertTrue(test_file.exists())
+            self.assertEqual(data, test_file.read_bytes())
+
+        self.assertFalse(test_file.exists())
+
     def test_temp_file_without_content(self):
         with temp_file(name="foo.bar") as test_file:
             self.assertTrue(test_file.exists())
