@@ -2,18 +2,6 @@
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
 #
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 import unittest
 from pathlib import Path
 from string import Template
@@ -140,9 +128,12 @@ class GetCurrentJavaVersionCommandTestCase(unittest.TestCase):
 
     def test_getting_version_no_files_configured(self):
         exp_err_msg = "no version found"
-        with temp_directory(change_into=True), self.assertRaisesRegex(
-            VersionError,
-            exp_err_msg,
+        with (
+            temp_directory(change_into=True),
+            self.assertRaisesRegex(
+                VersionError,
+                exp_err_msg,
+            ),
         ):
             version_file_path = Path("upgradeVersion.json")
             version_file_path.write_text(
@@ -159,9 +150,12 @@ class GetCurrentJavaVersionCommandTestCase(unittest.TestCase):
             r"No /tmp/.*/upgradeVersion\.json config file found\. "
             r"This file is required for pontos"
         )
-        with temp_directory(change_into=True), self.assertRaisesRegex(
-            VersionError,
-            exp_err_msg,
+        with (
+            temp_directory(change_into=True),
+            self.assertRaisesRegex(
+                VersionError,
+                exp_err_msg,
+            ),
         ):
             JavaVersionCommand(SemanticVersioningScheme).get_current_version()
 
@@ -203,9 +197,12 @@ class VerifyJavaVersionCommandTestCase(unittest.TestCase):
             + r"in '/tmp/.*/upgradeVersion\.json'"
         )
 
-        with temp_directory(change_into=True), self.assertRaisesRegex(
-            VersionError,
-            exp_err_msg,
+        with (
+            temp_directory(change_into=True),
+            self.assertRaisesRegex(
+                VersionError,
+                exp_err_msg,
+            ),
         ):
             version_file_path = Path("upgradeVersion.json")
             version_file_path.write_text(
@@ -362,9 +359,12 @@ class UpdateJavaVersionCommandTestCase(unittest.TestCase):
             "lineNo:4 "
             "content:'\n'"
         )
-        with temp_directory(change_into=True), self.assertRaisesRegex(
-            VersionError,
-            exp_err_msg,
+        with (
+            temp_directory(change_into=True),
+            self.assertRaisesRegex(
+                VersionError,
+                exp_err_msg,
+            ),
         ):
             version_file_path = Path("upgradeVersion.json")
             version_file_path.write_text(
