@@ -2,18 +2,6 @@
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
 #
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 import unittest
 from contextlib import redirect_stderr, redirect_stdout
@@ -21,7 +9,7 @@ from datetime import datetime
 from io import StringIO
 
 from pontos.testing import temp_directory
-from pontos.version.main import VersionExitCode, main
+from pontos.version._main import VersionExitCode, main
 
 
 class MainTestCase(unittest.TestCase):
@@ -30,17 +18,21 @@ class MainTestCase(unittest.TestCase):
             main([])
 
     def test_no_project(self):
-        with temp_directory(change_into=True), self.assertRaises(
-            SystemExit
-        ) as cm, redirect_stderr(StringIO()):
+        with (
+            temp_directory(change_into=True),
+            self.assertRaises(SystemExit) as cm,
+            redirect_stderr(StringIO()),
+        ):
             main(["show"])
 
         self.assertEqual(cm.exception.code, VersionExitCode.NO_PROJECT)
 
     def test_update_success(self):
-        with temp_directory(change_into=True) as temp_dir, redirect_stdout(
-            StringIO()
-        ) as out, self.assertRaises(SystemExit) as cm:
+        with (
+            temp_directory(change_into=True) as temp_dir,
+            redirect_stdout(StringIO()) as out,
+            self.assertRaises(SystemExit) as cm,
+        ):
             version_file = temp_dir / "package.json"
             version_file.write_text(
                 '{"name": "foo", "version": "1.2.3"}',
@@ -55,9 +47,11 @@ class MainTestCase(unittest.TestCase):
         self.assertEqual(cm.exception.code, VersionExitCode.SUCCESS)
 
     def test_update_failure(self):
-        with temp_directory(change_into=True) as temp_dir, redirect_stderr(
-            StringIO()
-        ), self.assertRaises(SystemExit) as cm:
+        with (
+            temp_directory(change_into=True) as temp_dir,
+            redirect_stderr(StringIO()),
+            self.assertRaises(SystemExit) as cm,
+        ):
             version_file = temp_dir / "package.json"
             version_file.write_text(
                 "{}",
@@ -68,9 +62,11 @@ class MainTestCase(unittest.TestCase):
         self.assertEqual(cm.exception.code, VersionExitCode.UPDATE_ERROR)
 
     def test_update_already_up_to_date(self):
-        with temp_directory(change_into=True) as temp_dir, redirect_stdout(
-            StringIO()
-        ) as out, self.assertRaises(SystemExit) as cm:
+        with (
+            temp_directory(change_into=True) as temp_dir,
+            redirect_stdout(StringIO()) as out,
+            self.assertRaises(SystemExit) as cm,
+        ):
             version_file = temp_dir / "package.json"
             version_file.write_text(
                 '{"name": "foo", "version": "1.2.3"}',
@@ -83,9 +79,11 @@ class MainTestCase(unittest.TestCase):
         self.assertEqual(cm.exception.code, VersionExitCode.SUCCESS)
 
     def test_show(self):
-        with temp_directory(change_into=True) as temp_dir, redirect_stdout(
-            StringIO()
-        ) as out, self.assertRaises(SystemExit) as cm:
+        with (
+            temp_directory(change_into=True) as temp_dir,
+            redirect_stdout(StringIO()) as out,
+            self.assertRaises(SystemExit) as cm,
+        ):
             version_file = temp_dir / "package.json"
             version_file.write_text(
                 '{"name": "foo", "version": "1.2.3"}',
@@ -98,9 +96,11 @@ class MainTestCase(unittest.TestCase):
         self.assertEqual(cm.exception.code, VersionExitCode.SUCCESS)
 
     def test_show_error(self):
-        with temp_directory(change_into=True) as temp_dir, redirect_stderr(
-            StringIO()
-        ) as out, self.assertRaises(SystemExit) as cm:
+        with (
+            temp_directory(change_into=True) as temp_dir,
+            redirect_stderr(StringIO()) as out,
+            self.assertRaises(SystemExit) as cm,
+        ):
             version_file = temp_dir / "package.json"
             version_file.write_text(
                 '{"name": "foo", "version": "abc"}',
@@ -115,9 +115,11 @@ class MainTestCase(unittest.TestCase):
         )
 
     def test_verify_failure(self):
-        with temp_directory(change_into=True) as temp_dir, redirect_stderr(
-            StringIO()
-        ) as out, self.assertRaises(SystemExit) as cm:
+        with (
+            temp_directory(change_into=True) as temp_dir,
+            redirect_stderr(StringIO()) as out,
+            self.assertRaises(SystemExit) as cm,
+        ):
             version_file = temp_dir / "package.json"
             version_file.write_text(
                 '{"name": "foo", "version": "1.2.3"}',
@@ -134,9 +136,10 @@ class MainTestCase(unittest.TestCase):
         self.assertEqual(cm.exception.code, VersionExitCode.VERIFY_ERROR)
 
     def test_verify_success(self):
-        with temp_directory(change_into=True) as temp_dir, self.assertRaises(
-            SystemExit
-        ) as cm:
+        with (
+            temp_directory(change_into=True) as temp_dir,
+            self.assertRaises(SystemExit) as cm,
+        ):
             version_file = temp_dir / "package.json"
             version_file.write_text(
                 '{"name": "foo", "version": "1.2.3"}',
@@ -147,9 +150,10 @@ class MainTestCase(unittest.TestCase):
         self.assertEqual(cm.exception.code, VersionExitCode.SUCCESS)
 
     def test_verify_current(self):
-        with temp_directory(change_into=True) as temp_dir, self.assertRaises(
-            SystemExit
-        ) as cm:
+        with (
+            temp_directory(change_into=True) as temp_dir,
+            self.assertRaises(SystemExit) as cm,
+        ):
             version_file = temp_dir / "package.json"
             version_file.write_text(
                 '{"name": "foo", "version": "1.2.3"}',
@@ -160,9 +164,11 @@ class MainTestCase(unittest.TestCase):
         self.assertEqual(cm.exception.code, VersionExitCode.SUCCESS)
 
     def test_next_invalid_current(self):
-        with redirect_stderr(StringIO()), temp_directory(
-            change_into=True
-        ) as temp_dir, self.assertRaises(SystemExit) as cm:
+        with (
+            redirect_stderr(StringIO()),
+            temp_directory(change_into=True) as temp_dir,
+            self.assertRaises(SystemExit) as cm,
+        ):
             version_file = temp_dir / "package.json"
             version_file.write_text(
                 '{"name": "foo", "version": "1.2.tt"}',
@@ -175,9 +181,11 @@ class MainTestCase(unittest.TestCase):
         )
 
     def test_next_dev(self):
-        with temp_directory(change_into=True) as temp_dir, redirect_stdout(
-            StringIO()
-        ) as out, self.assertRaises(SystemExit) as cm:
+        with (
+            temp_directory(change_into=True) as temp_dir,
+            redirect_stdout(StringIO()) as out,
+            self.assertRaises(SystemExit) as cm,
+        ):
             version_file = temp_dir / "package.json"
             version_file.write_text(
                 '{"name": "foo", "version": "1.2.3"}',
@@ -189,9 +197,11 @@ class MainTestCase(unittest.TestCase):
         self.assertEqual(out.getvalue(), "1.2.4.dev1\n")
 
     def test_next_patch(self):
-        with temp_directory(change_into=True) as temp_dir, redirect_stdout(
-            StringIO()
-        ) as out, self.assertRaises(SystemExit) as cm:
+        with (
+            temp_directory(change_into=True) as temp_dir,
+            redirect_stdout(StringIO()) as out,
+            self.assertRaises(SystemExit) as cm,
+        ):
             version_file = temp_dir / "package.json"
             version_file.write_text(
                 '{"name": "foo", "version": "1.2.3"}',
@@ -203,9 +213,11 @@ class MainTestCase(unittest.TestCase):
         self.assertEqual(out.getvalue(), "1.2.4\n")
 
     def test_next_minor(self):
-        with temp_directory(change_into=True) as temp_dir, redirect_stdout(
-            StringIO()
-        ) as out, self.assertRaises(SystemExit) as cm:
+        with (
+            temp_directory(change_into=True) as temp_dir,
+            redirect_stdout(StringIO()) as out,
+            self.assertRaises(SystemExit) as cm,
+        ):
             version_file = temp_dir / "package.json"
             version_file.write_text(
                 '{"name": "foo", "version": "1.2.3"}',
@@ -217,9 +229,11 @@ class MainTestCase(unittest.TestCase):
         self.assertEqual(out.getvalue(), "1.3.0\n")
 
     def test_next_major(self):
-        with temp_directory(change_into=True) as temp_dir, redirect_stdout(
-            StringIO()
-        ) as out, self.assertRaises(SystemExit) as cm:
+        with (
+            temp_directory(change_into=True) as temp_dir,
+            redirect_stdout(StringIO()) as out,
+            self.assertRaises(SystemExit) as cm,
+        ):
             version_file = temp_dir / "package.json"
             version_file.write_text(
                 '{"name": "foo", "version": "1.2.3"}',
@@ -231,9 +245,11 @@ class MainTestCase(unittest.TestCase):
         self.assertEqual(out.getvalue(), "2.0.0\n")
 
     def test_next_alpha(self):
-        with temp_directory(change_into=True) as temp_dir, redirect_stdout(
-            StringIO()
-        ) as out, self.assertRaises(SystemExit) as cm:
+        with (
+            temp_directory(change_into=True) as temp_dir,
+            redirect_stdout(StringIO()) as out,
+            self.assertRaises(SystemExit) as cm,
+        ):
             version_file = temp_dir / "package.json"
             version_file.write_text(
                 '{"name": "foo", "version": "1.2.3"}',
@@ -245,9 +261,11 @@ class MainTestCase(unittest.TestCase):
         self.assertEqual(out.getvalue(), "1.2.4-alpha1\n")
 
     def test_next_beta(self):
-        with temp_directory(change_into=True) as temp_dir, redirect_stdout(
-            StringIO()
-        ) as out, self.assertRaises(SystemExit) as cm:
+        with (
+            temp_directory(change_into=True) as temp_dir,
+            redirect_stdout(StringIO()) as out,
+            self.assertRaises(SystemExit) as cm,
+        ):
             version_file = temp_dir / "package.json"
             version_file.write_text(
                 '{"name": "foo", "version": "1.2.3"}',
@@ -259,9 +277,11 @@ class MainTestCase(unittest.TestCase):
         self.assertEqual(out.getvalue(), "1.2.4-beta1\n")
 
     def test_next_rc(self):
-        with temp_directory(change_into=True) as temp_dir, redirect_stdout(
-            StringIO()
-        ) as out, self.assertRaises(SystemExit) as cm:
+        with (
+            temp_directory(change_into=True) as temp_dir,
+            redirect_stdout(StringIO()) as out,
+            self.assertRaises(SystemExit) as cm,
+        ):
             version_file = temp_dir / "package.json"
             version_file.write_text(
                 '{"name": "foo", "version": "1.2.3"}',
@@ -274,9 +294,11 @@ class MainTestCase(unittest.TestCase):
 
     def test_next_calendar(self):
         today = datetime.today()
-        with temp_directory(change_into=True) as temp_dir, redirect_stdout(
-            StringIO()
-        ) as out, self.assertRaises(SystemExit) as cm:
+        with (
+            temp_directory(change_into=True) as temp_dir,
+            redirect_stdout(StringIO()) as out,
+            self.assertRaises(SystemExit) as cm,
+        ):
             version_file = temp_dir / "package.json"
             version_file.write_text(
                 '{"name": "foo", "version": "1.2.3"}',
